@@ -8,22 +8,23 @@ using namespace Qt::StringLiterals;
 
 Channel Channel::fromJson(const QJsonObject &obj, Channel &channel)
 {
-    const bool isPeerTube = obj.contains("id"_L1) && !obj.contains("nextpage"_L1);
+    const bool isPeerTube = obj.contains("avatars"_L1);
     const bool isPiped = obj.contains("url"_L1) || obj.contains("nextpage"_L1);
-    if (isPiped) {
+    if (isPeerTube) {
+        channel.m_id = obj["name"_L1].toString() + u"@" + obj["host"_L1].toString();
+        channel.m_name = obj["displayName"_L1].toString();
+        channel.m_description = obj["description"_L1].toString();
+        channel.m_subCount = obj["followersCount"_L1].toInt();
+        channel.m_avatar = obj["avatar"_L1].toObject()["path"_L1].toString();
+        const QJsonValue firstBanners = obj["banners"_L1].toArray().first();
+        channel.m_banner = firstBanners.toObject()["path"_L1].toString();
+    } else if (isPiped) {
         channel.m_id = obj["url"_L1].toString().remove(QStringLiteral("/channel/"));
         channel.m_name = obj["name"_L1].toString();
         channel.m_avatar = obj["avatarUrl"_L1].toString();
         channel.m_banner = obj["bannerUrl"_L1].toString();
         channel.m_description = obj["description"_L1].toString();
         channel.m_subCount = obj["subscriberCount"_L1].toInt();
-    } else if (isPeerTube) {
-        channel.m_name = obj["name"_L1].toString();
-        channel.m_description = obj["description"_L1].toString();
-        channel.m_subCount = obj["followersCount"_L1].toInt();
-        channel.m_avatar = obj["avatar"_L1].toObject()["path"_L1].toString();
-        const QJsonValue firstBanners = obj["banners"_L1].toArray().first();
-        channel.m_banner = firstBanners.toObject()["path"_L1].toString();
     } else {
         channel.m_id = obj["authorId"_L1].toString();
         channel.m_name = obj["author"_L1].toString();
